import { DatasourceOptions } from '@genesislcap/foundation-comms';
import { JsonFormsState, OwnPropsOfControl, RankedTester, StatePropsOfControl } from '@jsonforms/core';
import { RuleEffect, SchemaBasedCondition } from '@jsonforms/core';
import { ViewTemplate } from '@microsoft/fast-element';
import { ErrorObject } from 'ajv';
import { DispatchRenderer } from './jsonforms/renderers/dispatch-renderer';
export type { Layout, UISchemaElement } from '@jsonforms/core';
/**
 * The layouts and control types, which allow you to customize the arrangement of forms.
 * @public
 * */
export type UiSchemaElementType = 'Control' | 'VerticalLayout' | 'LayoutVertical2Columns' | 'Categorization' | 'Group' | 'Stepper' | 'HorizontalLayout';
/**
 * Available orientation for stepper renderer.
 * @public
 */
export type StepperOrientationType = 'vertical' | 'horizontal';
/**
 * Available aligment for labels.
 * @public
 */
export type LabelPlacementType = 'top' | 'left';
/**
 * Available configuration options for connected combobox/multiselect.
 * @public
 */
export type ConnectedRenderersOptions = {
    /**
     * Activates the async search by changing the criteria based on the value from the search-bar.
     * @public
     */
    async?: boolean;
    /**
     * The name of the target Data Server query or Request Server requestReply.
     * @public
     */
    allOptionsResourceName?: string;
    /**
     * A property that is set to configure the resource to which combobox/multiselect is connected.
     * @public
     */
    datasourceConfig?: DatasourceOptions;
    /**
     * Specifies which field should be used as underlying data used when changing selection.
     * @public
     */
    valueField?: string;
    /**
     * Field used to display label for the component.
     * @public
     */
    labelField?: string;
    /**
     * Property to which we can provide the data to be used instead of data from the server.
     * @public
     */
    data?: any[];
};
/**
 * Configuration options available for array renderer.
 * @public
 */
export type ArrayRendererOptions = {
    /**
     * ChildUiSchema allows you to pass a UiSchema for a particular element,
     * which can then be multiplied many times by the renderer.
     * @public
     */
    childUiSchema?: UiSchema;
};
/**
 * Orientation options available for stepper renderer.
 * @public
 */
export type StepperOrientationOptions = {
    /**
     * Configuration options available for the stepper renderer which set the renderer horizontally or vertically.
     * @public
     */
    orientation?: StepperOrientationType;
};
/**
 * Orientation options available for stepper renderer.
 * @public
 */
export type LabelPlacementOptions = {
    /**
     * Configuration options available for the labels alignment renderer which set the renderer top or left.
     * @public
     */
    labelPlacement?: LabelPlacementType;
};
/**
 * All configuration options that are available.
 * @public
 */
export type UiSchemaOptions = StepperOrientationOptions | LabelPlacementOptions;
/**
 * Configuration options available for categorization renderer.
 * @public
 */
export type CategorizationRendererOptions = {
    /**
     * childElements allows you to pass the UiSchema array in which the renderers groups will be located
     * @public
     */
    childElements?: UiSchema[];
};
/**
 * Configuration options available for group renderer.
 * @public
 */
export type GroupRendererOptions = CategorizationRendererOptions;
/**
 * Configuration options available for stepper renderer.
 * @public
 */
export type StepperRendererOptions = CategorizationRendererOptions;
/**
 * Configuration options available for string renderer.
 * @public
 */
export type StringRendererOptions = {
    /**
     * Changes the type attribute in the string renderer from text to password.
     * @public
     */
    isPassword?: boolean;
    /**
     * Setting this property enables text-area instead of text-field.
     * @public
     */
    textarea?: boolean;
};
/**
 * Standard configuration options available for all renderers.
 * @public
 */
export type StandardRendererOptions = {
    /**
     * Setting this property allows you to enable read only mode for the renderer.
     * @public
     */
    readonly?: boolean;
    /**
     * Setting this property allows you to hide the renderer.
     * @public
     */
    hidden?: boolean;
    /**
     * Setting this property enables client-side validation.
     * @public
     */
    validateFn?: (data: any, path: string, label: string) => ErrorObject[];
    i18n?: {
        [key: string]: any;
    };
    /**
     * Setting this property allows you to enable tooltip next to the label.
     * @public
     */
    tooltip?: string;
};
/**
 * All configuration options that are available.
 * @public
 */
export type UiSchemaElementOptions = ConnectedRenderersOptions | ArrayRendererOptions | CategorizationRendererOptions | GroupRendererOptions | StepperRendererOptions | StringRendererOptions | StandardRendererOptions;
/**
 * A UiSchemaElement that displays property values in a user interface element.
 * @public
 */
export type UiSchemaElement = {
    /**
     * The layouts and control types, which allow you to customize the arrangement of forms.
     * @public
     * */
    type: UiSchemaElementType;
    /**
     * The mandatory scope property, which expects a JSON schema reference value, defines to which property of the data the control should be bound to.
     * @public
     */
    scope: string;
    /**
     * By default, controls use the name of property they point to as a label.
     * Setting this property allows you to change the label.
     * @public
     */
    label?: string;
    /**
     * Setting this property allows you to change the placeholder in input renderers.
     * @public
     */
    placeholder?: string;
    /**
     * Optional attribute options that determine how the control is rendered.
     * @public
     */
    options?: UiSchemaElementOptions;
    /**
     * Rule with effect and condition {@link https://jsonforms.io/docs/uischema/rules}
     * @public
     */
    rule?: Rule;
};
type Rule = {
    condition: SchemaBasedCondition;
    effect: RuleEffect;
};
/**
 * The UI schema, which is passed to JSON Forms, describes the general layout of a form and is just a regular JSON object.
 * It describes the form by means of different UI schema elements, which can often be categorized into either Controls or Layouts.
 * @public
 */
export type UiSchema = {
    /**
     * The layouts and control types, which allow you to customize the arrangement of forms.
     * @public
     * */
    type: UiSchemaElementType;
    /**
     * All layouts need to declare an elements property which contains the children which are to be arranged by the layout.
     * It is expected to be an array of UI Schema elements, e.g. controls or other layouts.
     * @public
     */
    elements: UiSchemaElement[];
    /**
     * Optional attribute options that determine how the control is rendered.
     * @public
     */
    options?: UiSchemaOptions;
};
/** @public */
export type RendererEntry = {
    renderer: ViewTemplate<DispatchRenderer, any>;
    tester: RankedTester;
    mapper: (state: JsonFormsState, ownProps: OwnPropsOfControl) => StatePropsOfControl;
};
//# sourceMappingURL=types.d.ts.map